@@ -28,6 +28,8 @@ test_that("iv_robust matches AER + ivpack", {
 
   skip_if_not_installed("AER")
   skip_if_not_installed("ivpack")
+  skip("ivpack is not available")
+
   ivco <- iv_robust(y ~ x | z, data = dat, se_type = "classical")
   ivfit <- AER::ivreg(y ~ x | z, data = dat)
   ivo <- summary(ivfit)
@@ -323,6 +325,8 @@ test_that("iv_robust matches AER + clubSandwich", {
 
 test_that("iv_robust different specifications work", {
   skip_if_not_installed("AER")
+  skip_if_not_installed("ivpack")
+  skip("ivpack not available")
 
   # More instruments than endog. regressors
   ivro <- iv_robust(mpg ~ wt | hp + cyl, data = mtcars, se_type = "HC0")
@@ -439,6 +443,8 @@ test_that("S3 methods", {
 
 test_that("IV diagnostics", {
 
+  skip_if_not_installed("AER")
+
   # Load stata diagnostics
   stata_diags <- read.table(
     "stata-iv-diagnostics.txt",
